@@ -1,5 +1,6 @@
 #' @title Asynchronous Model Based Optimization
 #'
+#' @include OptimizerMbo.R
 #' @name mlr_optimizers_async_mbo
 #'
 #' @description
@@ -38,6 +39,8 @@
 #' Otherwise, if it is `NULL`, an initial design of size `design_size` will be generated based on the `generate_design` sampling function.
 #' See also the parameters below.
 #'
+#' @inheritSection mlr_optimizers_mbo Conditions
+#'
 #' @section Parameters:
 #' \describe{
 #' \item{`initial_design`}{`data.table::data.table()`\cr
@@ -201,7 +204,7 @@ OptimizerAsyncMbo = R6Class("OptimizerAsyncMbo",
       }
 
       if (is.null(self$acq_optimizer)) {
-        self$acq_optimizer = default_acqoptimizer(self$acq_function)
+        self$acq_optimizer = default_acqoptimizer(self$acq_function, inst)
       }
 
       if (is.null(self$result_assigner)) {
@@ -347,12 +350,12 @@ OptimizerAsyncMbo = R6Class("OptimizerAsyncMbo",
           self$acq_function$update()
           xdt = self$acq_optimizer$optimize()
           transpose_list(xdt)[[1L]]
-        }, mbo_error = function(mbo_error_condition) {
-            lg$info(paste0(class(mbo_error_condition), collapse = " / "))
-            lg$info("Proposing a randomly sampled point")
-            xdt = generate_design_random(inst$search_space, n = 1L)$data
-            transpose_list(xdt)[[1L]]
-          })
+        }, Mlr3ErrorMbo = function(cond) {
+          lg$warn("Caught the following error: %s", cond$message)
+          lg$info("Proposing a randomly sampled point")
+          xdt = generate_design_random(inst$search_space, n = 1L)$data
+          transpose_list(xdt)[[1L]]
+        })
 
         # eval
         get_private(inst)$.eval_point(xs)
@@ -362,7 +365,7 @@ OptimizerAsyncMbo = R6Class("OptimizerAsyncMbo",
         tryCatch(
           {
             self$surrogate$update()
-          }, surrogate_update_error = function(error_condition) {
+          }, Mlr3ErrorMboSurrogateUpdate = function(error_condition) {
             lg$warn("Could not update the surrogate a final time after the optimization process has terminated.")
           }
         )
