@@ -108,6 +108,12 @@ MAKE_DESIGN = function(instance, n = 4L) {
   generate_design_random(instance$search_space, n)$data
 }
 
+skip_if_missing_regr_km = function() {
+  skip_if_not_installed("mlr3learners")
+  skip_if_not_installed("DiceKriging")
+  skip_if_not_installed("rgenoud")
+}
+
 if (requireNamespace("mlr3learners") && requireNamespace("DiceKriging") && requireNamespace("rgenoud")) {
   library(mlr3learners)
   REGR_KM_NOISY = lrn("regr.km", covtype = "matern3_2", optim.method = "gen", control = list(trace = FALSE), nugget.estim = TRUE, jitter = 1e-12)
@@ -157,7 +163,7 @@ LearnerRegrError = R6::R6Class("LearnerRegrError",
   private = list(
     .train = function(task) {
       if (self$param_set$values$error_train) {
-        stop("Surrogate Train Error.")
+        mlr3misc::error_learner_train("Surrogate Train Error.")
       } else {
         mu = mean(task$data(cols = task$target_names)[[1L]])
         sigma = sd(task$data(cols = task$target_names)[[1L]])
@@ -167,7 +173,7 @@ LearnerRegrError = R6::R6Class("LearnerRegrError",
 
     .predict = function(task) {
       if (self$param_set$values$error_predict) {
-        stop("Surrogate Predict Error.")
+        mlr3misc::error_learner_predict("Surrogate Predict Error.")
       } else {
         n = task$nrow
         if (self$predict_type == "se") {
