@@ -13,7 +13,9 @@ test_that("default bayesopt_parego", {
   acq_optimizer = AcqOptimizer$new(opt("random_search", batch_size = 2L), terminator = trm("evals", n_evals = 2L))
   bayesopt_parego(instance, surrogate = surrogate, acq_function = acq_function, acq_optimizer = acq_optimizer)
   expect_true(nrow(instance$archive$data) == 5L)
+  expect_true(sum(is.na(instance$archive$data$acq_ei)) == 4L)
   expect_true("y_scal" %in% colnames(instance$archive$data))
   expect_true(!is.na(instance$archive$data$acq_ei[5L]))
+  expect_true(is.na(instance$archive$data$y_scal[5L]))
 })
 
